@@ -7,8 +7,10 @@ import statsmodels.formula.api as smf
 from statsmodels.tools.sm_exceptions import DomainWarning
 import matplotlib.pyplot as plt
 
-from zepid.causal.utils import (propensity_score, plot_boxplot, plot_kde, plot_love, stochastic_check_conditional,
-                                standardized_mean_differences, positivity, _bounding_, iptw_calculator)
+from zepid.calc.utils import probability_bounds
+from zepid.causal.utils import (check_input_data, propensity_score, plot_boxplot, plot_kde, plot_love,
+                                stochastic_check_conditional, standardized_mean_differences, positivity,
+                                iptw_calculator)
 
 
 class IPTW:
@@ -147,32 +149,16 @@ class IPTW:
     See http://chrp.org/love/JSM2004RoundTableHandout. pdf, 1364.
     """
     def __init__(self, df, treatment, outcome, weights=None, standardize='population'):
-        if df.dropna(subset=[d for d in df.columns if d != outcome]).shape[0] != df.shape[0]:
-            warnings.warn("There is missing data that is not the outcome in the data set. IPTW will drop "
-                          "all missing data that is not missing outcome data. IPTW will fit "
-                          + str(df.dropna(subset=[d for d in df.columns if d != outcome]).shape[0]) +
-                          ' of ' + str(df.shape[0]) + ' observations', UserWarning)
-            self.df = df.copy().dropna(subset=[d for d in df.columns if d != outcome]).reset_index()
-        else:
-            self.df = df.copy().reset_index()
-
-        # Checking to see if missing outcome data occurs
-        self._missing_indicator = '__missing_indicator__'
-        if self.df.dropna(subset=[outcome]).shape[0] != self.df.shape[0]:
-            self._miss_flag = True
-            self.df[self._missing_indicator] = np.where(self.df[outcome].isna(), 0, 1)
-        else:
-            self._miss_flag = False
-            self.df[self._missing_indicator] = 1
-
         self.treatment = treatment
         self.outcome = outcome
-
-        if df[outcome].dropna().value_counts().index.isin([0, 1]).all():
-            self._continuous_outcome = False
-        else:
-            self._continuous_outcome = True
-
+        self._missing_indicator = '__missing_indicator__'
+        self.df, self._miss_flag, self._continuous_outcome = check_input_data(data=df,
+                                                                              exposure=treatment,
+                                                                              outcome=outcome,
+                                                                              estimator="IPTW",
+                                                                              drop_censoring=False,
+                                                                              drop_missing=True,
+                                                                              binary_exposure_only=True)
         # TODO add detection of continuous treatments
 
         self.average_treatment_effect = None
@@ -182,6 +168,11 @@ class IPTW:
 
         if standardize in ['population', 'exposed', 'unexposed']:
             self.standardize = standardize
+            if standardize in ['exposed', 'unexposed']:
+                warnings.warn("For the ATT and the ATU, confidence intervals calculated using the robust-variance "
+                              "approach (what is currently done in zEpid) may underestimate the variance. Therefore "
+                              "when requesting the ATT or the ATU, it is recommended to use bootstrapped confidence "
+                              "intervals instead.", UserWarning)
         else:
             raise ValueError('Please specify one of the currently supported weighting schemes: ' +
                              'population, exposed, unexposed')
@@ -296,7 +287,7 @@ class IPTW:
             n = 1
 
         if bound:  # Bounding predicted probabilities if requested
-            d = _bounding_(fitmodel.predict(self.df), bounds=bound)
+            d = probability_bounds(fitmodel.predict(self.df), bounds=bound)
         else:
             d = fitmodel.predict(self.df)
 
@@ -328,10 +319,8 @@ class IPTW:
         """
         if self.__mdenom is None:
             raise ValueError('No model has been fit to generated predicted probabilities')
-
         if self.ms_model is None:
             raise ValueError('No marginal structural model has been specified')
-
         if self._miss_flag and not self._fit_missing_:
             warnings.warn("All missing outcome data is assumed to be missing completely at random. To relax this "
                           "assumption to outcome data is missing at random please use the `missing_model()` "
@@ -715,18 +704,18 @@ class StochasticIPTW:
     Biometrics, 68(2), 541-549.
     """
     def __init__(self, df, treatment, outcome, weights=None):
-        if df.dropna().shape[0] != df.shape[0]:
-            warnings.warn("There is missing data in the dataset. StochasticIPTW will drop all missing data. "
-                          "StochasticIPTW will fit " + str(df.dropna().shape[0]) + ' of ' + str(df.shape[0]) +
-                          " observations", UserWarning)
-        self.df = df.copy().dropna().reset_index()
-
         self.treatment = treatment
         self.outcome = outcome
+        self._missing_indicator = '__missing_indicator__'
+        self.df, self._miss_flag, self._continuous_outcome = check_input_data(data=df,
+                                                                              exposure=treatment,
+                                                                              outcome=outcome,
+                                                                              estimator="StochasticIPTW",
+                                                                              drop_censoring=True,
+                                                                              drop_missing=True,
+                                                                              binary_exposure_only=True)
         self.weights = weights
-
         self.marginal_outcome = np.nan
-
         self._pdenom_ = None
 
     def treatment_model(self, model, print_results=True):
